@@ -1,10 +1,11 @@
-# Copyrights 2003,2004,2007 by Mark Overmeer <perl@overmeer.net>.
-# For other contributors see Changes.
+# Copyrights 2003,2004,2007-2009 by Mark Overmeer <perl@overmeer.net>.
+#  For other contributors see Changes.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 0.99.
+# Pod stripped from pm file by OODoc 1.06.
 package Mail::Identity;
 use vars '$VERSION';
-$VERSION = '0.91';
+$VERSION = '0.93';
+
 use base 'User::Identity::Item';
 
 use strict;
@@ -37,7 +38,7 @@ sub init($)
 
 
 sub from($)
-{   my ($class, $other) = @_;
+{   my ($class, $other) = (shift, shift);
     return $other if $other->isa(__PACKAGE__);
 
     if($other->isa('Mail::Address'))
